==> microb-eal_2.4.6.17-1.1+0m5.tar.gz: microb-eal-2.4.6.17/src/gecko/MicrobEalUtils.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:set ts=2 sw=2 sts=2 tw=80 et cindent: */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Oleg Romashin <romaxa@gmail.com>
 *
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef __MICROBEALUTILS_H__
#define __MICROBEALUTILS_H__

#include "glib.h"
#include "gmozillaengine.h"
#include "nsIDOMWindow.h"
#include "nsIDOMNode.h"
#include "nsIContentViewer.h"
#include "nsIWebBrowser.h"
#include "nsCOMPtr.h"
#include "nsIViewManager.h"

#ifdef __cplusplus /* If this is a C++ compiler, use C linkage */
extern "C" {
#endif

GMozillaEngine* GetGMozEngineForDOMWindow(nsIDOMWindow* aDOMWindow, GObject** aMozEmbed = NULL);
nsresult GetDOMWindowByNode(nsIDOMNode *aNode, nsIDOMWindow * *aDOMWindow);
nsresult GetContentViewer(nsIWebBrowser *webBrowser, nsIContentViewer **aViewer);
nsresult GetSendEventTools(GMozillaEngine *self, nsIWidget * *aWidget, nsIViewManager **aViewMgr = NULL, nsIDOMWindow * *aDOMWindow = NULL);

#ifdef __cplusplus /* If this is a C++ compiler, end C linkage */
}
#endif

#endif  // __MICROBEALUTILS_H__

==> microb-eal_2.9.5-1.23+0m5.tar.gz: microb-eal-2.9.5/src/gecko/MicrobEalUtils.h <==
/* -*- Mode: C++; tab-width: 2; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:set ts=2 sw=2 sts=2 tw=80 et cindent: */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Oleg Romashin <romaxa@gmail.com>
 *
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef __MICROBEALUTILS_H__
#define __MICROBEALUTILS_H__

#include "glib.h"
#include "gmozillaengine.h"
#include "nsIDOMWindow.h"
#include "nsIDOMNode.h"
#include "nsIContentViewer.h"
#include "nsIWebBrowser.h"
#include "nsCOMPtr.h"
#include "nsIViewManager.h"
#include "nsStringAPI.h"

#ifdef __cplusplus /* If this is a C++ compiler, use C linkage */
extern "C" {
#endif

GMozillaEngine* GetGMozEngineForDOMWindow(nsIDOMWindow* aDOMWindow, GObject** aMozEmbed = NULL);
nsresult GetDOMWindowByNode(nsIDOMNode *aNode, nsIDOMWindow * *aDOMWindow);
nsresult GetContentViewer(nsIWebBrowser *webBrowser, nsIContentViewer **aViewer);
nsresult GetSendEventTools(GMozillaEngine *self, nsIWidget * *aWidget, nsIViewManager **aViewMgr = NULL, nsIDOMWindow * *aDOMWindow = NULL);
/**
 * Checks if aSource is a logical id for a string. If it is
 * assign the localized string to aTarget and return PR_TRUE,
 * otherwise return PR_FALSE.
 */
PRBool CheckLogicalId(const nsAString& aSource, nsString& aTarget);

#ifdef __cplusplus /* If this is a C++ compiler, end C linkage */
}
#endif

#endif  // __MICROBEALUTILS_H__
